@@ -412,11 +412,14 @@ rstto_file_get_content_type ( RsttoFile *r_file )
                 content_type = magic_file (magic, file_path);
                 if ( NULL != content_type )
                 {
-                    /* "image/x-ms-bmp" isn't supported by gdk_pixbuf_loader_new_with_mime_type ()
-                       see https://bugzilla.xfce.org/show_bug.cgi?id=13489 */
+                    /* image types that aren't supported by gdk_pixbuf_loader_new_with_mime_type () */
                     if ( g_strcmp0 (content_type, "image/x-ms-bmp") == 0 )
                     {
-                        content_type = "image/bmp";
+                        content_type = "image/bmp"; // bug #13489
+                    }
+                    else if ( g_strcmp0 (content_type, "image/x-portable-greymap") == 0 )
+                    {
+                        content_type = "image/x-portable-graymap"; // bug #14709
                     }
 
                     r_file->priv->content_type = g_strdup (content_type);
@@ -462,6 +465,19 @@ rstto_file_get_modified_time ( RsttoFile *r_file )
     return time_;
 }
 
+goffset
+rstto_file_get_size (RsttoFile *r_file )
+{
+    goffset size = 0;
+    GFileInfo *file_info = g_file_query_info (r_file->priv->file, G_FILE_ATTRIBUTE_STANDARD_SIZE, 0, NULL, NULL);
+
+    size = g_file_info_get_size ( file_info );
+
+    g_object_unref (file_info);
+
+    return size;
+}
+
 ExifEntry *
 rstto_file_get_exif ( RsttoFile *r_file, ExifTag id )
 {
@@ -583,15 +599,16 @@ rstto_file_get_thumbnail (
 
     thumbnail_path = rstto_file_get_thumbnail_path (r_file);
 
+    thumbnailer = rstto_thumbnailer_new();
+    rstto_thumbnailer_queue_file (thumbnailer, r_file);
+
     if (NULL == thumbnail_path)
     {
         /* No thumbnail to return at this time */
+        g_object_unref (thumbnailer);
         return NULL;
     }
 
-    thumbnailer = rstto_thumbnailer_new();
-    rstto_thumbnailer_queue_file (thumbnailer, r_file);
-
     /* FIXME:
      *
      * The thumbnail should be updated on the "ready" signal
