@@ -395,8 +395,7 @@ rstto_recent_chooser_get_items (
         all_items_iter = g_list_next (all_items_iter);
     }
 
-    g_list_foreach (all_items, (GFunc)gtk_recent_info_unref, NULL);
-    g_list_free (all_items);
+    g_list_free_full (all_items, (GDestroyNotify) gtk_recent_info_unref);
 
     return items;
 }
